==> ms_3.3.tar.gz: ms_3.3/mapserv.h <==
#ifndef MAPSERV_H
#define MAPSERV_H

#ifdef _WIN32
#include <process.h>
#endif

#include <ctype.h>
#include <time.h>

#include "map.h"

#include "cgiutil.h"

/*
** Defines
*/
#define MAXCLICK 1000
#define MINCLICK -1000
#define MAXIMGSIZE 1024
#define MAXZOOM 25
#define MINZOOM -25
#define NUMEXP "[-]?(([0-9]+)|([0-9]*[.][0-9]+)([eE][-+]?[0-9]+)?)"
#define EXTENT_PADDING .05

extern int enter_string;

/*
** Macros
*/
#define TEMPLATE_TYPE(s)  (((strncmp("http://", s, 7) == 0) || (strncmp("ftp://", s, 6)) == 0)  ? MS_URL : MS_FILE)

/*
** Enumerated types
*/
enum modes {BROWSE, ZOOMIN, ZOOMOUT, MAP, LEGEND, REFERENCE, SCALEBAR, COORDINATE, QUERY, QUERYMAP, ITEMQUERY, ITEMQUERYMAP, NQUERY, NQUERYMAP, ITEMNQUERY, ITEMNQUERYMAP, FEATUREQUERY, FEATUREQUERYMAP, FEATURENQUERY, FEATURENQUERYMAP};
enum coordSources {NONE, FROMIMGPNT, FROMIMGBOX, FROMREFPNT, FROMUSERPNT, FROMUSERBOX, FROMBUF, FROMSCALE, FROMSEARCHBOX};

/*
** Global variables
*/
int UseShapes = MS_FALSE; /* are results of a query to be used in calculating an extent of some sort */
int SearchMap = MS_FALSE;

entry Entries[MAX_ENTRIES];
int NumEntries=0;

mapObj *Map=NULL;

char *Layers[MS_MAXLAYERS];
int NumLayers=0; /* number of layers specfied by a user */

char *SelectLayer=NULL;
queryResultObj *FeatureQueryResults=NULL;

rectObj ShpExt; /* these 2 vars hold everything that can be returned to the client for a query */
queryObj *Query;

char *QueryLayer=NULL;
queryResultObj *QueryResults=NULL;
char *Item=NULL, *Value=NULL;
int QueryCoordSource=NONE;

rectObj RawExt={-1.0,-1.0,-1.0,-1.0};

int ImgRows=-1, ImgCols=-1;
rectObj ImgExt={-1.0,-1.0,-1.0,-1.0}; /* Existing image's mapextent */
rectObj ImgBox={-1.0,-1.0,-1.0,-1.0};
pointObj MapPnt={-1.0, -1.0};
pointObj RefPnt={-1.0, -1.0};
pointObj ImgPnt={-1.0, -1.0};

int CoordSource=NONE;

double Buffer=0; /* used to create a map extent around a point */
double fZoom=1, Zoom=1; /* default for browsing */
int ZoomDirection=0; /* whether zooming in or out, default is pan or 0 */
int ZoomSize=0; /* zoom absolute magnitude (i.e. > 0) */

int Mode=BROWSE; /* can be BROWSE, QUERY, etc. */
char Id[128]; /* big enough for time + pid */

/* 
** variables for multiple query results processing 
*/
int RN=0; /* overall result number */
int LRN=0; /* result number within a layer */
char *CL=NULL; /* current layer */
char *CD=NULL; /* current layer description */
int NL=0; /* total number of layers with results */
int NR=0; /* total number or results */

#endif /* MAPSERV_H */

==> ms_3.3.010.tar.gz: ms_3.3.010/mapserv.h <==
#ifndef MAPSERV_H
#define MAPSERV_H

#ifdef _WIN32
#include <process.h>
#endif

#include <ctype.h>
#include <time.h>

#include "map.h"

#include "cgiutil.h"

/*
** Defines
*/
#define MAXCLICK 1000
#define MINCLICK -1000
#define MAXIMGSIZE 1024
#define MAXZOOM 25
#define MINZOOM -25
#define NUMEXP "[-]?(([0-9]+)|([0-9]*[.][0-9]+)([eE][-+]?[0-9]+)?)"
#define EXTENT_PADDING .05

extern int enter_string;

/*
** Macros
*/
#define TEMPLATE_TYPE(s)  (((strncmp("http://", s, 7) == 0) || (strncmp("ftp://", s, 6)) == 0)  ? MS_URL : MS_FILE)

/*
** Enumerated types (PROCESSING is a EGIS mode only)
*/
enum modes {BROWSE, ZOOMIN, ZOOMOUT, MAP, LEGEND, REFERENCE, SCALEBAR, COORDINATE, QUERY, QUERYMAP, ITEMQUERY, ITEMQUERYMAP, NQUERY, NQUERYMAP, ITEMNQUERY, ITEMNQUERYMAP, FEATUREQUERY, FEATUREQUERYMAP, FEATURENQUERY, FEATURENQUERYMAP, PROCESSING};
enum coordSources {NONE, FROMIMGPNT, FROMIMGBOX, FROMREFPNT, FROMUSERPNT, FROMUSERBOX, FROMBUF, FROMSCALE, FROMSEARCHBOX};

/*
** Global variables
*/
int UseShapes=MS_FALSE; // are results of a query to be used in calculating an extent of some sort
int SearchMap=MS_FALSE; // apply pan/zoom BEFORE doing the query (e.g. query the output image rather than the input image)
int SaveMap=MS_FALSE, SaveQuery=MS_FALSE; // should the query and/or map be saved 

entry Entries[MAX_ENTRIES];
int NumEntries=0;

mapObj *Map=NULL;

char *Layers[MS_MAXLAYERS];
int NumLayers=0; /* number of layers specfied by a user */

rectObj ShpExt; /* these 3 vars hold everything that can be returned to the client for a query */
queryObj *Query=NULL;
int ShpIdx;

char *QueryFile=NULL;
char *QueryLayer=NULL, *SelectLayer=NULL;
queryResultObj *QueryResults=NULL;
char *Item=NULL, *Value=NULL;

rectObj RawExt={-1.0,-1.0,-1.0,-1.0};

int ImgRows=-1, ImgCols=-1;
rectObj ImgExt={-1.0,-1.0,-1.0,-1.0}; /* Existing image's mapextent */
rectObj ImgBox={-1.0,-1.0,-1.0,-1.0};
pointObj MapPnt={-1.0, -1.0};
pointObj RefPnt={-1.0, -1.0};
pointObj ImgPnt={-1.0, -1.0};

int QueryCoordSource=NONE, CoordSource=NONE;

double Buffer=0; /* used to create a map extent around a point */
double fZoom=1, Zoom=1; /* default for browsing */
int ZoomDirection=0; /* whether zooming in or out, default is pan or 0 */
int ZoomSize=0; /* zoom absolute magnitude (i.e. > 0) */

int Mode=BROWSE; /* can be BROWSE, QUERY, etc. */
char Id[128]; /* big enough for time + pid */

/* 
** variables for multiple query results processing 
*/
int RN=0; /* overall result number */
int LRN=0; /* result number within a layer */
char *CL=NULL; /* current layer */
char *CD=NULL; /* current layer description */
int NL=0; /* total number of layers with results */
int NR=0; /* total number or results */
int NLR=0; /* number of results in a layer */

#endif /* MAPSERV_H */
